==> jc-1.4.0.tar.gz: jas/LdcOperand.h <==
// class jas.LdcOperand

// class file dependencies
// @dep_class 2c401db3553feabf jas_InsnOperand
// @dep_class 8220ce9b63ceca62 jas_LdcOperand
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header jas_InsnOperand

#include "jas/InsnOperand.h"

#ifndef _JC_jas_LdcOperand_H_
#define _JC_jas_LdcOperand_H_

// Forward structure declarations
struct _jc_jas_CP$object;
struct _jc_jas_ClassEnv$object;
struct _jc_jas_CodeAttr$object;
struct _jc_jas_Insn$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_jas_LdcOperand$sub_refs	_jc_jas_LdcOperand$sub_refs;
typedef struct _jc_jas_LdcOperand$sub_nonrefs	_jc_jas_LdcOperand$sub_nonrefs;
typedef struct _jc_jas_LdcOperand$refs	_jc_jas_LdcOperand$refs;
typedef struct _jc_jas_LdcOperand$nonrefs	_jc_jas_LdcOperand$nonrefs;
typedef struct _jc_jas_LdcOperand$object	_jc_jas_LdcOperand$object;

typedef const struct _jc_jas_LdcOperand$vmethods	_jc_jas_LdcOperand$vmethods;
typedef const struct _jc_jas_LdcOperand$vtable	_jc_jas_LdcOperand$vtable;
typedef const struct _jc_jas_LdcOperand$vtype	_jc_jas_LdcOperand$vtype;

// Constructors
extern void _jc_jas_LdcOperand$method$_init$c4fcc8207a69695a(_jc_env *, struct _jc_jas_LdcOperand$object *, struct _jc_jas_Insn$object *, struct _jc_jas_CP$object *);
extern void _jc_jas_LdcOperand$method$_init$764647af5dcac11a(_jc_env *, struct _jc_jas_LdcOperand$object *, struct _jc_jas_Insn$object *, struct _jc_jas_CP$object *, jboolean);

// Virtual methods
extern void _jc_jas_LdcOperand$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_LdcOperand$object *, struct _jc_jas_ClassEnv$object *);
extern jint _jc_jas_LdcOperand$method$size$ed865933e174f90a(_jc_env *, struct _jc_jas_LdcOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *);
extern void _jc_jas_LdcOperand$method$write$d61e8c36d8c1cacd(_jc_env *, struct _jc_jas_LdcOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *);

// Virtual method descriptors
extern _jc_method _jc_jas_LdcOperand$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_LdcOperand$method_info$size$ed865933e174f90a;
extern _jc_method _jc_jas_LdcOperand$method_info$write$d61e8c36d8c1cacd;

// Virtual methods structure
struct _jc_jas_LdcOperand$vmethods {
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_LdcOperand$object *, struct _jc_jas_ClassEnv$object *);
	jint	(*size$ed865933e174f90a)(_jc_env *, struct _jc_jas_LdcOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *);
	void	(*write$d61e8c36d8c1cacd)(_jc_env *, struct _jc_jas_LdcOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *);
};

// Vtable
struct _jc_jas_LdcOperand$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_InsnOperand$vmethods	jas_InsnOperand;
	_jc_jas_LdcOperand$vmethods	jas_LdcOperand;
};

// Vtype
struct _jc_jas_LdcOperand$vtype {
	_jc_type			type;
	_jc_jas_LdcOperand$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_LdcOperand$sub_refs {
	struct _jc_jas_CP$object	*cpe;
	struct _jc_jas_Insn$object	*source;
};

// Reference instance fields (object)
struct _jc_jas_LdcOperand$refs {
    _jc_jas_LdcOperand$sub_refs	jas_LdcOperand;
    _jc_jas_InsnOperand$sub_refs	jas_InsnOperand;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_LdcOperand$sub_nonrefs {
	jboolean	wide;
};

// Non-reference instance fields (object)
struct _jc_jas_LdcOperand$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_InsnOperand$sub_nonrefs	jas_InsnOperand;
    _jc_jas_LdcOperand$sub_nonrefs	jas_LdcOperand;
};

// Object instance structure
struct _jc_jas_LdcOperand$object {
	_jc_jas_LdcOperand$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_LdcOperand$vtype	*vtype;
	_jc_jas_LdcOperand$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_LdcOperand$vtype _jc_jas_LdcOperand$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_LdcOperand, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_LdcOperand$class_object;

#endif	/* _JC_jas_LdcOperand_H_ */

==> jc-1.4.6.tar.gz: jas/LdcOperand.h <==
// class jas.LdcOperand

// class file dependencies
// @dep_class 2c401db3553feabf jas_InsnOperand
// @dep_class 8220ce9b63ceca62 jas_LdcOperand
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header jas_InsnOperand

#include "jas/InsnOperand.h"

#ifndef _JC_jas_LdcOperand_H_
#define _JC_jas_LdcOperand_H_

// Forward structure declarations
struct _jc_jas_CP$object;
struct _jc_jas_ClassEnv$object;
struct _jc_jas_CodeAttr$object;
struct _jc_jas_Insn$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_jas_LdcOperand$sub_refs	_jc_jas_LdcOperand$sub_refs;
typedef struct _jc_jas_LdcOperand$sub_nonrefs	_jc_jas_LdcOperand$sub_nonrefs;
typedef struct _jc_jas_LdcOperand$refs	_jc_jas_LdcOperand$refs;
typedef struct _jc_jas_LdcOperand$nonrefs	_jc_jas_LdcOperand$nonrefs;
typedef struct _jc_jas_LdcOperand$object	_jc_jas_LdcOperand$object;

typedef const struct _jc_jas_LdcOperand$vmethods	_jc_jas_LdcOperand$vmethods;
typedef const struct _jc_jas_LdcOperand$vtable	_jc_jas_LdcOperand$vtable;
typedef const struct _jc_jas_LdcOperand$vtype	_jc_jas_LdcOperand$vtype;

// Constructors
extern void _jc_jas_LdcOperand$method$_init$c4fcc8207a69695a(_jc_env *, struct _jc_jas_LdcOperand$object *, struct _jc_jas_Insn$object *, struct _jc_jas_CP$object *) _JC_JCNI_ATTR;
extern void _jc_jas_LdcOperand$method$_init$764647af5dcac11a(_jc_env *, struct _jc_jas_LdcOperand$object *, struct _jc_jas_Insn$object *, struct _jc_jas_CP$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_jas_LdcOperand$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_LdcOperand$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
extern jint _jc_jas_LdcOperand$method$size$ed865933e174f90a(_jc_env *, struct _jc_jas_LdcOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *) _JC_JCNI_ATTR;
extern void _jc_jas_LdcOperand$method$write$d61e8c36d8c1cacd(_jc_env *, struct _jc_jas_LdcOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_jas_LdcOperand$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_LdcOperand$method_info$size$ed865933e174f90a;
extern _jc_method _jc_jas_LdcOperand$method_info$write$d61e8c36d8c1cacd;

// Virtual methods structure
struct _jc_jas_LdcOperand$vmethods {
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_LdcOperand$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
	jint	(*size$ed865933e174f90a)(_jc_env *, struct _jc_jas_LdcOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *) _JC_JCNI_ATTR;
	void	(*write$d61e8c36d8c1cacd)(_jc_env *, struct _jc_jas_LdcOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_jas_LdcOperand$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_InsnOperand$vmethods	jas_InsnOperand;
	_jc_jas_LdcOperand$vmethods	jas_LdcOperand;
};

// Vtype
struct _jc_jas_LdcOperand$vtype {
	_jc_type			type;
	_jc_jas_LdcOperand$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_LdcOperand$sub_refs {
	struct _jc_jas_CP$object	*cpe;
	struct _jc_jas_Insn$object	*source;
};

// Reference instance fields (object)
struct _jc_jas_LdcOperand$refs {
    _jc_jas_LdcOperand$sub_refs	jas_LdcOperand;
    _jc_jas_InsnOperand$sub_refs	jas_InsnOperand;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_LdcOperand$sub_nonrefs {
	jboolean	wide;
};

// Non-reference instance fields (object)
struct _jc_jas_LdcOperand$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_InsnOperand$sub_nonrefs	jas_InsnOperand;
    _jc_jas_LdcOperand$sub_nonrefs	jas_LdcOperand;
};

// Object instance structure
struct _jc_jas_LdcOperand$object {
	_jc_jas_LdcOperand$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_LdcOperand$vtype	*vtype;
	_jc_jas_LdcOperand$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_LdcOperand$vtype _jc_jas_LdcOperand$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_LdcOperand, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_LdcOperand$class_object;

#endif	/* _JC_jas_LdcOperand_H_ */
